==> cms-db_v0.7.9.tar.gz: admin/users.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('edituser');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php
		if (isset($_POST['button'])) {
			include('../data/users/root.php');
			if (sha1('root.php'.$_POST['oldpass']) == $pass && $_POST['pass'] == $_POST['repeat']) {
				$pass = sha1('root.php'.$_POST['pass']);
				$writethis = '<?php
				$user = "'.$_POST['user'].'";
				$pass = "'.$pass.'";
				?>';
				$datei = fopen('../data/users/root.php','w+');
				fwrite($datei,$writethis);
				fclose($datei);
				echo '<p class="hint">'.locale('desc_settings-saved',true).'</p>';
			} else {
				echo '<p class="error">'.locale('desc_error-invalid-data',true).'</p>';
			}
		} elseif (isset($_GET['deluser'])) {
			echo '<p class="hint">'.sprintf(locale('desc_user-deleted',true), $_GET['deluser']).'</p>';
		} elseif (isset($_GET['saved'])) {
			echo '<p class="hint">'.sprintf(locale('desc_user-saved',true), $_GET['saved']).'</p>';
		}
		include('../data/users/root.php');
		?>

		<h2><?php locale('title') ?></h2>
		<h3><?php locale('title_root') ?></h3>
		<p>
			<form action="users.php?<?php echo SID ?>" method="POST">
				<?php locale('label_username') ?>: <input type="text" name="user" value="<?php echo $user ?>" /><br />
				<?php locale('label_oldpw') ?> <input type="password" name="oldpass" value="" /><br />
				<?php locale('label_newpw') ?> <input type="password" name="pass" value="" /><br />
				<?php locale('desc_repeat') ?> <input type="password" name="repeat" value="" /><br />
				<input type="submit" name="button" value="<?php locale('button_save') ?>">
			</form>
		</p>
		<p>
			<i><?php locale('desc_root') ?></i>
		</p>
		<h3><?php locale('title_users') ?></h3>
		<p>
		<?php
		$vorhanden = false;
		if ($handle = opendir('../data/users')) {
			while (false !== ($file = readdir($handle))) {
				if($file != '.' && $file != '..' && $file != 'root.php') {
					include('../data/users/'.$file);
					echo $user.' - <a href="edituser.php?user='.$file.'&'.SID.'">'.locale('link_edit',true).'</a> - <a href="deluser.php?user='.$file.'&'.SID.'">'.locale('link_delete',true).'</a><br />';
					$vorhanden = true;
				}
			}
			closedir($handle);
		}
		if (!$vorhanden) {
			locale('desc_no-users');
		}
		?>
		</p>
		<p>
			<a href="newuser.php?<?php echo SID ?>"><?php locale('link_newuser') ?></a>
		</p>


	</body>
</html>

==> cms-db_v0.7.11.tar.gz: admin/users.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('root');
include('locale.inc.php');
$locale = new LocalizingClass('edituser');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title><?php locale('title') ?></title>
		<meta http-equiv="content-type" content="text/html; charset=utf-8" />
		<link rel="stylesheet" type="text/css" href="style.css" />
		<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
	</head>
	<body>

		<h1><?php locale('desc_settings') ?></h1>

		<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="users.php?<?php echo SID ?>" class="nonewtab active"><?php locale('link_usersettings') ?></a></li><li><a href="commonsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_commonsettings') ?></a></li><li><a href="url.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_urlsettings') ?></a></li><li><a href="ftpsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_ftpsettings') ?></a></li><li><a href="adminsettings.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_adminsettings') ?></a></li><li><a href="locale.php?<?php echo SID ?>" class="nonewtab"><?php locale('link_localesettings') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

		<?php
		include('escape.inc.php');
		if (isset($_POST['button'])) {
			include('../data/users/root.php');
			if (sha1('root.php'.$_POST['oldpass']) == $pass && $_POST['pass'] == $_POST['repeat']) {
				$pass = sha1('root.php'.escapeSL($_POST['pass']));
				$writethis = '<?php
				$user = \''.escapeForm($_POST['user']).'\';
				$pass = \''.escapeSave($pass).'\';
				?>';
				file_put_contents('../data/users/root.php', $writethis);
				echo '<p class="hint">'.locale('desc_settings-saved',true).'</p>';
			} else {
				echo '<p class="error">'.locale('desc_error-invalid-data',true).'</p>';
			}
		} elseif (isset($_GET['deluser'])) {
			echo '<p class="hint">'.sprintf(locale('desc_user-deleted',true), $_GET['deluser']).'</p>';
		} elseif (isset($_GET['saved'])) {
			echo '<p class="hint">'.sprintf(locale('desc_user-saved',true), $_GET['saved']).'</p>';
		}
		include('../data/users/root.php');
		?>

		<h2><?php locale('title') ?></h2>
		<h3><?php locale('title_root') ?></h3>
		<p>
			<form action="users.php?<?php echo SID ?>" method="POST">
				<?php locale('label_username') ?>: <input type="text" name="user" value="<?php echo htmlspecialchars($user) ?>" /><br />
				<?php locale('label_oldpw') ?> <input type="password" name="oldpass" value="" /><br />
				<?php locale('label_newpw') ?> <input type="password" name="pass" value="" /><br />
				<?php locale('desc_repeat') ?> <input type="password" name="repeat" value="" /><br />
				<input type="submit" name="button" value="<?php locale('button_save') ?>">
			</form>
		</p>
		<p>
			<i><?php locale('desc_root') ?></i>
		</p>
		<h3><?php locale('title_users') ?></h3>
		<p>
		<?php
		$vorhanden = false;
		if ($handle = opendir('../data/users')) {
			while (false !== ($file = readdir($handle))) {
				if($file != '.' && $file != '..' && $file != 'root.php') {
					include('../data/users/'.$file);
					echo htmlspecialchars($user).' - <a href="edituser.php?user='.$file.'&'.SID.'">'.locale('link_edit',true).'</a> - <a href="deluser.php?user='.$file.'&'.SID.'">'.locale('link_delete',true).'</a><br />';
					$vorhanden = true;
				}
			}
			closedir($handle);
		}
		if (!$vorhanden) {
			locale('desc_no-users');
		}
		?>
		</p>
		<p>
			<a href="newuser.php?<?php echo SID ?>"><?php locale('link_newuser') ?></a>
		</p>


	</body>
</html>
